#
# spec file for package python-baron
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-baron
Version:        0.10.1
Release:        2.1
Summary:        Full Syntax Tree for Python
License:        LGPL-3.0-or-later
Group:          Development/Languages/Python
URL:            https://github.com/PyCQA/baron
Source0:        https://files.pythonhosted.org/packages/source/b/baron/baron-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-rply
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module rply}
# /SECTION
%python_subpackages

%description
Baron is a Full Syntax Tree (FST) library for Python. In contrast
to an AST which drops some syntax information in the process of its
creation (like empty lines, comments, formatting), a FST keeps
everything and guarantees the operation
fst_to_code(code_to_fst(source_code)) == source_code.

%prep
%setup -q -n baron-%{version}
# remove cache files accidentaly put in sdist
rm -f tests/*.pyc
rm -r tests/__pycache__

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest tests/

%files %{python_files}
%doc CHANGELOG README.md
%license LICENSE
%{python_sitelib}/baron
%{python_sitelib}/baron-%{version}*-info

%changelog
* Tue May 13 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Sun Jan 23 2022 Dirk Müller <dmueller@suse.com>
- update to 0.10.1:
  * bug fix: in "a._" the "._" part was incorrectly recognized as a float
  * bug fix: baron is now able to parse "class A(b, c=d): pass"
  * some project cleaned and integration of tox with good pratices like flake8 and check-manifest
  * bug fix for missing edge case in inner formatting
  * complet support for float with underscores in them
  * bug fix for failure of parsing of "{**a}"
* Wed Mar  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.9:
  * BREAKING CHANGE: annotations are now member of {def,list,dict}_argument to flatten the data structure
  * add support for ... in from import by bram
  * add support for return annotation by bram
  * add support for exec function by bram
  * add support for variable annotation #145 by scottbelden and additional work by bram
  * add support for *var expressions in tuple assignment by bram
  * add support for raise from #120 by odcinek with additional work by bram
  * add support for arglist usage in class definition inheritence by bram
  * bug fix by 91e839a kyleatmakrs
* Tue Dec  4 2018 Jan Engelhardt <jengelh@inai.de>
- Grammar fix.
* Fri Oct 20 2017 toddrme2178@gmail.com
- initial version
